==> ckan-2.0.tar.gz: ckan-2.0/ckan/public/base/i18n/es.js <==
{
  "": {
    "domain": "ckan",
    "lang": "es",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Ocurrió un error"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "¿Está seguro de que desea realizar esta acción?"
  ],
  "Cancel": [
    null,
    "Cancelar"
  ],
  "Confirm": [
    null,
    "Confirmar"
  ],
  "Edit": [
    null,
    "Editar"
  ],
  "Failed to load data API information": [
    null,
    "Falló carga de información de datos de API"
  ],
  "Follow": [
    null,
    "Seguir"
  ],
  "Hide": [
    null,
    "Esconder"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Ingreso es muy corto, debe tener al menos un caracter"
  ],
  "Loading...": [
    null,
    "Cargando ..."
  ],
  "No matches found": [
    null,
    "No se encontraron coincidencias"
  ],
  "Please Confirm Action": [
    null,
    "Por favor confirme la acción"
  ],
  "Resource uploaded": [
    null,
    "Recurso subido"
  ],
  "Show more": [
    null,
    "Mostrar más"
  ],
  "Start typing…": [
    null,
    "Comience a escribir..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Existen modificaciones no guardadas para este formulario"
  ],
  "There is no API data to load for this resource": [
    null,
    "No existen datos de API para cargar para este recurso"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "No se pudo autenticar subida"
  ],
  "Unable to get data for uploaded file": [
    null,
    "No se pudo obtener datos para el archivo subido"
  ],
  "Unable to upload file": [
    null,
    "No se pudo subir el archivo"
  ],
  "Unfollow": [
    null,
    "Dejar de seguir"
  ],
  "Upload a file": [
    null,
    "Sube un archivo"
  ],
  "show less": [
    null,
    "mostrar menos"
  ],
  "show more": [
    null,
    "mostrar más"
  ]
}

==> ckan-2.1.tar.gz: ckan-2.1/ckan/public/base/i18n/es.js <==
{
  "": {
    "domain": "ckan",
    "lang": "es",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Ocurrió un error"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "¿Está seguro de que desea realizar esta acción?"
  ],
  "Cancel": [
    null,
    "Cancelar"
  ],
  "Confirm": [
    null,
    "Confirmar"
  ],
  "Edit": [
    null,
    "Editar"
  ],
  "Failed to load data API information": [
    null,
    "Falló carga de información de datos de API"
  ],
  "Follow": [
    null,
    "Seguir"
  ],
  "Hide": [
    null,
    "Esconder"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Ingreso es muy corto, debe tener al menos un caracter"
  ],
  "Loading...": [
    null,
    "Cargando ..."
  ],
  "No matches found": [
    null,
    "No se encontraron coincidencias"
  ],
  "Please Confirm Action": [
    null,
    "Por favor confirme la acción"
  ],
  "Resource uploaded": [
    null,
    "Recurso subido"
  ],
  "Show more": [
    null,
    "Mostrar más"
  ],
  "Start typing…": [
    null,
    "Comience a escribir..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Existen modificaciones no guardadas para este formulario"
  ],
  "There is no API data to load for this resource": [
    null,
    "No existen datos de API para cargar para este recurso"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "No se pudo autenticar subida"
  ],
  "Unable to get data for uploaded file": [
    null,
    "No se pudo obtener datos para el archivo subido"
  ],
  "Unable to upload file": [
    null,
    "No se pudo subir el archivo"
  ],
  "Unfollow": [
    null,
    "Dejar de seguir"
  ],
  "Upload a file": [
    null,
    "Sube un archivo"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Estás subiendo un fichero. Estás seguro que quieres salir y parar esta subida?"
  ],
  "show less": [
    null,
    "mostrar menos"
  ],
  "show more": [
    null,
    "mostrar más"
  ]
}
